==> ejc-sddjsorg-impl-3.0.0-20211019.091636-32-sources.jar: com/ejianc/business/sddjsorg/bean/OrgApplyFileSetEntity.java <==
package com.ejianc.business.sddjsorg.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 组织机构申请-资料设置
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_org_apply_file_set")
public class OrgApplyFileSetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="name")
    private java.lang.String name; // 档案资料名称
    @TableField(value="required")
    private Boolean required; // 是否必须上传
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="in_use")
    private Boolean inUse; // 是否启用
    @TableField(value="type")
    private java.lang.String type; // 类型：set:设立申请，change：变更，del：注销，merge：合并，divide：分立，supplementary:补录
    @TableField(value="check_time")
    private String checkTime; // 校验时间点：submit:提交时校验，supplement:补充信息保存时校验，file:归档时校验
    
    
    

    /**
     * 档案资料名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 档案资料名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 是否必须上传
     */
    public Boolean getRequired() {
        return required;
    }

    public void setRequired(Boolean required) {
        this.required = required;
    }

    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 是否启用
     */
    public Boolean getInUse() {
        return inUse;
    }

    public void setInUse(Boolean inUse) {
        this.inUse = inUse;
    }

    /**
     * 类型：set:设立申请，change：变更，del：注销，merge：合并，divide：分立，supplementary:补录
     */
    public java.lang.String getType() {
        return type;
    }

    /**
     * 类型：set:设立申请，change：变更，del：注销，merge：合并，divide：分立，supplementary:补录
     */
    public void setType(java.lang.String type) {
        this.type = type;
    }

    public String getCheckTime() {
        return checkTime;
    }

    public void setCheckTime(String checkTime) {
        this.checkTime = checkTime;
    }
}

==> ejc-sddjsorg-impl-3.0.0-20211210.032802-147-sources.jar: com/ejianc/business/sddjsorg/bean/OrgApplyFileSetEntity.java <==
package com.ejianc.business.sddjsorg.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 组织机构申请-资料设置
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_org_apply_file_set")
public class OrgApplyFileSetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="name")
    private java.lang.String name; // 档案资料名称
    @TableField(value="required")
    private Boolean required; // 是否必须上传
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="in_use")
    private Boolean inUse; // 是否启用
    @TableField(value="type")
    private java.lang.String type; // 类型：set:设立申请，change：变更，del：注销，merge：合并，divide：分立，supplementary:补录，decision：股东决策
    @TableField(value="check_time")
    private String checkTime; // 校验时间点：submit:提交时校验，supplement:补充信息保存时校验，file:归档时校验
    
    
    

    /**
     * 档案资料名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 档案资料名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 是否必须上传
     */
    public Boolean getRequired() {
        return required;
    }

    public void setRequired(Boolean required) {
        this.required = required;
    }

    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 是否启用
     */
    public Boolean getInUse() {
        return inUse;
    }

    public void setInUse(Boolean inUse) {
        this.inUse = inUse;
    }

    /**
     * 类型：set:设立申请，change：变更，del：注销，merge：合并，divide：分立，supplementary:补录
     */
    public java.lang.String getType() {
        return type;
    }

    /**
     * 类型：set:设立申请，change：变更，del：注销，merge：合并，divide：分立，supplementary:补录
     */
    public void setType(java.lang.String type) {
        this.type = type;
    }

    public String getCheckTime() {
        return checkTime;
    }

    public void setCheckTime(String checkTime) {
        this.checkTime = checkTime;
    }
}
